@@ -12,6 +12,9 @@ pub enum ChannelType {
     GuildCategory = 4,
     GuildNews = 5,
     GuildStore = 6,
+    GuildNewsThread = 10,
+    GuildPublicThread = 11,
+    GuildPrivateThread = 12,
     GuildStageVoice = 13,
 }
 
@@ -21,6 +24,9 @@ impl ChannelType {
             Self::Group => "Group",
             Self::GuildCategory => "GuildCategory",
             Self::GuildNews => "GuildNews",
+            Self::GuildNewsThread => "GuildNewsThread",
+            Self::GuildPrivateThread => "GuildPrivateThread",
+            Self::GuildPublicThread => "GuildPublicThread",
             Self::GuildStageVoice => "GuildStageVoice",
             Self::GuildStore => "GuildStore",
             Self::GuildText => "GuildText",
@@ -44,6 +50,9 @@ mod tests {
         serde_test::assert_tokens(&ChannelType::GuildCategory, &[Token::U8(4)]);
         serde_test::assert_tokens(&ChannelType::GuildNews, &[Token::U8(5)]);
         serde_test::assert_tokens(&ChannelType::GuildStore, &[Token::U8(6)]);
+        serde_test::assert_tokens(&ChannelType::GuildNewsThread, &[Token::U8(10)]);
+        serde_test::assert_tokens(&ChannelType::GuildPublicThread, &[Token::U8(11)]);
+        serde_test::assert_tokens(&ChannelType::GuildPrivateThread, &[Token::U8(12)]);
         serde_test::assert_tokens(&ChannelType::GuildStageVoice, &[Token::U8(13)]);
     }
 
@@ -52,6 +61,9 @@ mod tests {
         assert_eq!("Group", ChannelType::Group.name());
         assert_eq!("GuildCategory", ChannelType::GuildCategory.name());
         assert_eq!("GuildNews", ChannelType::GuildNews.name());
+        assert_eq!("GuildNewsThread", ChannelType::GuildNewsThread.name());
+        assert_eq!("GuildPrivateThread", ChannelType::GuildPrivateThread.name());
+        assert_eq!("GuildPublicThread", ChannelType::GuildPublicThread.name());
         assert_eq!("GuildStageVoice", ChannelType::GuildStageVoice.name());
         assert_eq!("GuildStore", ChannelType::GuildStore.name());
         assert_eq!("GuildText", ChannelType::GuildText.name());
