@@ -3,7 +3,7 @@ use crate::{
     id::{RoleId, UserId},
 };
 
-#[derive(Clone, Default, Debug, Eq, PartialEq)]
+#[derive(Clone, Debug, Default, Eq, PartialEq)]
 pub struct AllowedMentionsBuilder(AllowedMentions);
 
 impl AllowedMentionsBuilder {
@@ -105,6 +105,18 @@ mod tests {
         AllowedMentionsBuilder,
     };
     use crate::id::{RoleId, UserId};
+    use static_assertions::assert_impl_all;
+    use std::fmt::Debug;
+
+    assert_impl_all!(
+        AllowedMentionsBuilder: Clone,
+        Debug,
+        Default,
+        Eq,
+        PartialEq,
+        Send,
+        Sync
+    );
 
     #[test]
     fn test_max_mentioned() {
@@ -130,17 +142,23 @@ mod tests {
     fn test_validation() {
         let value = AllowedMentionsBuilder::new()
             .users()
-            .user_ids(vec![UserId(100), UserId(200)])
+            .user_ids(vec![
+                UserId::new(100).expect("non zero"),
+                UserId::new(200).expect("non zero"),
+            ])
             .roles()
-            .role_ids(vec![RoleId(300)])
+            .role_ids(vec![RoleId::new(300).expect("non zero")])
             .build();
 
         assert_eq!(
             value,
             AllowedMentions {
                 parse: vec![],
-                users: vec![UserId(100), UserId(200)],
-                roles: vec![RoleId(300)],
+                users: vec![
+                    UserId::new(100).expect("non zero"),
+                    UserId::new(200).expect("non zero")
+                ],
+                roles: vec![RoleId::new(300).expect("non zero")],
                 replied_user: false,
             },
         );
