@@ -144,8 +144,9 @@ mod tests {
             interaction: None,
             kind: MessageType::Regular,
             member: Some(PartialMember {
+                avatar: None,
                 deaf: false,
-                joined_at: Some(joined_at),
+                joined_at,
                 mute: false,
                 nick: Some("member nick".to_owned()),
                 permissions: None,
@@ -235,7 +236,6 @@ mod tests {
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("joined_at"),
-                Token::Some,
                 Token::Str("2020-01-01T00:00:00.000000+00:00"),
                 Token::Str("mute"),
                 Token::Bool(false),
@@ -335,8 +335,9 @@ mod tests {
             interaction: None,
             kind: MessageType::Regular,
             member: Some(PartialMember {
+                avatar: None,
                 deaf: false,
-                joined_at: Some(joined_at),
+                joined_at,
                 mute: false,
                 nick: Some("member nick".to_owned()),
                 permissions: None,
@@ -480,7 +481,6 @@ mod tests {
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("joined_at"),
-                Token::Some,
                 Token::Str("2020-01-01T00:00:00.000000+00:00"),
                 Token::Str("mute"),
                 Token::Bool(false),
